LocalScaling — scikit-hubness 0.21a1 documentation

# LocalScaling

class `skhubness.reduction.` `LocalScaling`(k: int = 5, method: str = 'standard', verbose: int = 0)

  Bases: `object`

  Hubness reduction with local scaling.

  Methods Summary

  `fit`(self, neigh_dist, neigh_ind, assume_sorted) |
  `transform`(self, neigh_dist, neigh_ind, …) |

  Methods Documentation

  `fit`(self, neigh_dist, neigh_ind, assume_sorted: 'bool' = True) → 'LocalScaling'
  `transform`(self, neigh_dist, neigh_ind, assume_sorted: 'bool' = True, *args, **kwargs) → '(np.ndarray, np.ndarray)'